@@ -7,10 +7,6 @@ type SliceOfByteSlice [][]byte
 
 func (s SliceOfByteSlice) Len() int { return len(s) }
 func (s SliceOfByteSlice) Less(i, j int) bool {
-	c := bytes.Compare(s[i], s[j])
-	if c == -1 {
-		return true
-	}
-	return false
+	return bytes.Compare(s[i], s[j]) < 0
 }
 func (s SliceOfByteSlice) Swap(i, j int) { s[i], s[j] = s[j], s[i] }
